sphinxcontrib_jsmath: Sphinx extension which renders display math in HTML via JavaScript
========================================================================================

Description
-----------

Sphinx extension which renders display math in HTML via JavaScript

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/sphinxcontrib-jsmath/

